[TEP-COMMIT] [CVS catalog] Fix Singapore address format to resolve bug# 1949
tmoulton-OfajU3CKLf1/[email protected] 6 Aug 2004 10:59:17 -0000
| Newsgroups | gmane.comp.web.oscommerce.cvs |
|---|---|
| Message-ID | <[email protected]> |
Commit in catalog/catalog/install on MAIN
oscommerce.sql +3 -2 1.100 -> 1.101
Fix Singapore address format to resolve bug# 1949
----------
catalog /catalog /install
oscommerce.sql 1.100 -> 1.101
diff -u -r1.100 -r1.101
--- oscommerce.sql 2004/07/22 21:03:35 1.100
+++ oscommerce.sql 2004/08/06 10:59:11 1.101
@@ -594,7 +594,7 @@
PRIMARY KEY (association_id)
);
# 1 - Default, 2 - USA, 3 - Spain, 4 - Singapore, 5 - Germany
INSERT INTO osc_address_format VALUES (1, '$firstname $lastname$cr$streets$cr$city, $postcode$cr$statecomma$country','$city / $country');
INSERT INTO osc_address_format VALUES (2, '$firstname $lastname$cr$streets$cr$city, $state $postcode$cr$country','$city, $state / $country');
INSERT INTO osc_address_format VALUES (3, '$firstname $lastname$cr$streets$cr$city$cr$postcode - $statecomma$country','$state / $country');
@@ -606,6 +606,7 @@
INSERT INTO osc_address_format VALUES (9, '$firstname $lastname$cr$streets$cr$postcode $city $state$cr$country','$city / $country');
INSERT INTO osc_address_format VALUES (10, '$firstname $lastname$cr$streets$cr$city$cr$postcode $country','$city / $country');
INSERT INTO osc_address_format VALUES (11, '$firstname $lastname$cr$streets$cr$city$cr$state$cr$postcode$cr$country','$city / $country');
+INSERT INTO osc_address_format VALUES (12, '$firstname $lastname$cr$streets$cr$city$cr$country $postcode','$city / $country');
INSERT INTO osc_configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Store Name', 'STORE_NAME', 'osCommerce', 'The name of my store', '1', '1', now());
INSERT INTO osc_configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Store Owner', 'STORE_OWNER', 'Harald Ponce de Leon', 'The name of my store owner', '1', '2', now());
@@ -967,7 +968,7 @@
INSERT INTO osc_countries VALUES (185,'Senegal','SN','SEN','1');
INSERT INTO osc_countries VALUES (186,'Seychelles','SC','SYC','1');
INSERT INTO osc_countries VALUES (187,'Sierra Leone','SL','SLE','1');
-INSERT INTO osc_countries VALUES (188,'Singapore','SG','SGP', '8');
+INSERT INTO osc_countries VALUES (188,'Singapore','SG','SGP', '12');
INSERT INTO osc_countries VALUES (189,'Slovakia (Slovak Republic)','SK','SVK','1');
INSERT INTO osc_countries VALUES (190,'Slovenia','SI','SVN','1');
INSERT INTO osc_countries VALUES (191,'Solomon Islands','SB','SLB','1');
CVSspam 0.2.9
-------------------------------------------------------
This SF.Net email is sponsored by OSTG. Have you noticed the changes on
Linux.com, ITManagersJournal and NewsForge in the past few weeks? Now,
one more big change to announce. We are now OSTG- Open Source Technology
@@ -594,7 +594,7 @@
PRIMARY KEY (association_id)
);
-# 1 - Default, 2 - USA, 3 - Spain, 4 - Singapore, 5 - Germany
+# 1 - Default, 2 - USA, 3 - Spain, 12 - Singapore, 5 - Germany
INSERT INTO osc_address_format VALUES (1, '$firstname $lastname$cr$streets$cr$city, $postcode$cr$statecomma$country','$city / $country');
INSERT INTO osc_address_format VALUES (2, '$firstname $lastname$cr$streets$cr$city, $state $postcode$cr$country','$city, $state / $country');
Group. Come see the changes on the new OSTG site. www.ostg.com